@@ -49,10 +49,10 @@ def oswritebytes(fd, obj):
     os.write(fd, tobytes(obj))
 
 
-
 def StdCaptureFD(out=True, err=True, in_=True):
     return capture.MultiCapture(out, err, in_, Capture=capture.FDCapture)
 
+
 def StdCapture(out=True, err=True, in_=True):
     return capture.MultiCapture(out, err, in_, Capture=capture.SysCapture)
 
@@ -72,7 +72,7 @@ class TestCaptureManager(object):
 
     @needsosdup
     @pytest.mark.parametrize("method",
-        ['no', 'sys', pytest.mark.skipif('not hasattr(os, "dup")', 'fd')])
+                             ['no', 'sys', pytest.mark.skipif('not hasattr(os, "dup")', 'fd')])
     def test_capturing_basic_api(self, method):
         capouter = StdCaptureFD()
         old = sys.stdout, sys.stderr, sys.stdin
@@ -83,14 +83,14 @@ class TestCaptureManager(object):
             assert outerr == ("", "")
             outerr = capman.suspendcapture()
             assert outerr == ("", "")
-            print ("hello")
+            print("hello")
             out, err = capman.suspendcapture()
             if method == "no":
                 assert old == (sys.stdout, sys.stderr, sys.stdin)
             else:
                 assert not out
             capman.resumecapture()
-            print ("hello")
+            print("hello")
             out, err = capman.suspendcapture()
             if method != "no":
                 assert out == "hello\n"
@@ -112,7 +112,7 @@ class TestCaptureManager(object):
 
 @pytest.mark.parametrize("method", ['fd', 'sys'])
 def test_capturing_unicode(testdir, method):
-    if hasattr(sys, "pypy_version_info") and sys.pypy_version_info < (2,2):
+    if hasattr(sys, "pypy_version_info") and sys.pypy_version_info < (2, 2):
         pytest.xfail("does not work on pypy < 2.2")
     if sys.version_info >= (3, 0):
         obj = "'b\u00f6y'"
@@ -234,7 +234,7 @@ class TestPerTestCapturing(object):
             "setup func1*",
             "in func1*",
             "teardown func1*",
-            #"*1 fixture failure*"
+            # "*1 fixture failure*"
         ])
 
     def test_teardown_capturing_final(self, testdir):
@@ -288,7 +288,7 @@ class TestLoggingInteraction(object):
                 stream.close() # to free memory/release resources
         """)
         result = testdir.runpytest_subprocess(p)
-        result.stderr.str().find("atexit") == -1
+        assert result.stderr.str().find("atexit") == -1
 
     def test_logging_and_immediate_setupteardown(self, testdir):
         p = testdir.makepyfile("""
@@ -305,7 +305,7 @@ class TestLoggingInteraction(object):
                 assert 0
         """)
         for optargs in (('--capture=sys',), ('--capture=fd',)):
-            print (optargs)
+            print(optargs)
             result = testdir.runpytest_subprocess(p, *optargs)
             s = result.stdout.str()
             result.stdout.fnmatch_lines([
@@ -331,7 +331,7 @@ class TestLoggingInteraction(object):
                 assert 0
         """)
         for optargs in (('--capture=sys',), ('--capture=fd',)):
-            print (optargs)
+            print(optargs)
             result = testdir.runpytest_subprocess(p, *optargs)
             s = result.stdout.str()
             result.stdout.fnmatch_lines([
@@ -355,7 +355,7 @@ class TestLoggingInteraction(object):
         """)
         result = testdir.runpytest_subprocess(
             p, "--traceconfig",
-            "-p", "no:capturelog")
+            "-p", "no:capturelog", "-p", "no:hypothesis", "-p", "no:hypothesispytest")
         assert result.ret != 0
         result.stdout.fnmatch_lines([
             "*hello432*",
@@ -705,6 +705,7 @@ def tmpfile(testdir):
     if not f.closed:
         f.close()
 
+
 @needsosdup
 def test_dupfile(tmpfile):
     flist = []
@@ -715,25 +716,37 @@ def test_dupfile(tmpfile):
         assert nf not in flist
         print(i, end="", file=nf)
         flist.append(nf)
+
+    fname_open = flist[0].name
+    assert fname_open == repr(flist[0].buffer)
+
     for i in range(5):
         f = flist[i]
         f.close()
+    fname_closed = flist[0].name
+    assert fname_closed == repr(flist[0].buffer)
+    assert fname_closed != fname_open
     tmpfile.seek(0)
     s = tmpfile.read()
     assert "01234" in repr(s)
     tmpfile.close()
+    assert fname_closed == repr(flist[0].buffer)
+
 
 def test_dupfile_on_bytesio():
     io = py.io.BytesIO()
     f = capture.safe_text_dupfile(io, "wb")
     f.write("hello")
     assert io.getvalue() == b"hello"
+    assert 'BytesIO object' in f.name
+
 
 def test_dupfile_on_textio():
     io = py.io.TextIO()
     f = capture.safe_text_dupfile(io, "wb")
     f.write("hello")
     assert io.getvalue() == "hello"
+    assert not hasattr(f, 'name')
 
 
 @contextlib.contextmanager
@@ -876,7 +889,7 @@ class TestStdCapture(object):
 
     def test_capturing_readouterr(self):
         with self.getcapture() as cap:
-            print ("hello world")
+            print("hello world")
             sys.stderr.write("hello error\n")
             out, err = cap.readouterr()
             assert out == "hello world\n"
@@ -887,7 +900,7 @@ class TestStdCapture(object):
 
     def test_capturing_readouterr_unicode(self):
         with self.getcapture() as cap:
-            print ("hx\xc4\x85\xc4\x87")
+            print("hx\xc4\x85\xc4\x87")
             out, err = cap.readouterr()
         assert out == py.builtin._totext("hx\xc4\x85\xc4\x87\n", "utf8")
 
@@ -902,7 +915,7 @@ class TestStdCapture(object):
 
     def test_reset_twice_error(self):
         with self.getcapture() as cap:
-            print ("hello")
+            print("hello")
             out, err = cap.readouterr()
         pytest.raises(ValueError, cap.stop_capturing)
         assert out == "hello\n"
@@ -916,7 +929,7 @@ class TestStdCapture(object):
             sys.stderr.write("world")
             sys.stdout = capture.CaptureIO()
             sys.stderr = capture.CaptureIO()
-            print ("not seen")
+            print("not seen")
             sys.stderr.write("not seen\n")
             out, err = cap.readouterr()
         assert out == "hello"
@@ -926,9 +939,9 @@ class TestStdCapture(object):
 
     def test_capturing_error_recursive(self):
         with self.getcapture() as cap1:
-            print ("cap1")
+            print("cap1")
             with self.getcapture() as cap2:
-                print ("cap2")
+                print("cap2")
                 out2, err2 = cap2.readouterr()
                 out1, err1 = cap1.readouterr()
         assert out1 == "cap1\n"
@@ -958,9 +971,9 @@ class TestStdCapture(object):
         assert sys.stdin is old
 
     def test_stdin_nulled_by_default(self):
-        print ("XXX this test may well hang instead of crashing")
-        print ("XXX which indicates an error in the underlying capturing")
-        print ("XXX mechanisms")
+        print("XXX this test may well hang instead of crashing")
+        print("XXX which indicates an error in the underlying capturing")
+        print("XXX mechanisms")
         with self.getcapture():
             pytest.raises(IOError, "sys.stdin.read()")
 
@@ -1037,6 +1050,15 @@ def test_capture_not_started_but_reset():
     capsys.stop_capturing()
 
 
+def test_using_capsys_fixture_works_with_sys_stdout_encoding(capsys):
+    test_text = 'test text'
+
+    print(test_text.encode(sys.stdout.encoding, 'replace'))
+    (out, err) = capsys.readouterr()
+    assert out
+    assert err == ''
+
+
 @needsosdup
 @pytest.mark.parametrize('use', [True, False])
 def test_fdcapture_tmpfile_remains_the_same(tmpfile, use):
@@ -1052,6 +1074,7 @@ def test_fdcapture_tmpfile_remains_the_same(tmpfile, use):
     capfile2 = cap.err.tmpfile
     assert capfile2 == capfile
 
+
 @needsosdup
 def test_close_and_capture_again(testdir):
     testdir.makepyfile("""
@@ -1071,7 +1094,6 @@ def test_close_and_capture_again(testdir):
     """)
 
 
-
 @pytest.mark.parametrize('method', ['SysCapture', 'FDCapture'])
 def test_capturing_and_logging_fundamentals(testdir, method):
     if method == "StdCaptureFD" and not hasattr(os, 'dup'):
@@ -1118,6 +1140,23 @@ def test_error_attribute_issue555(testdir):
     reprec.assertoutcome(passed=1)
 
 
+@pytest.mark.skipif(not sys.platform.startswith('win') and sys.version_info[:2] >= (3, 6),
+                    reason='only py3.6+ on windows')
+def test_py36_windowsconsoleio_workaround_non_standard_streams():
+    """
+    Ensure _py36_windowsconsoleio_workaround function works with objects that
+    do not implement the full ``io``-based stream protocol, for example execnet channels (#2666).
+    """
+    from _pytest.capture import _py36_windowsconsoleio_workaround
+
+    class DummyStream:
+        def write(self, s):
+            pass
+
+    stream = DummyStream()
+    _py36_windowsconsoleio_workaround(stream)
+
+
 def test_dontreadfrominput_has_encoding(testdir):
     testdir.makepyfile("""
         import sys
