@@ -1,7 +1,9 @@
 from __future__ import absolute_import, division, print_function
-import pytest, py
+import pytest
+import py
+
+from _pytest.main import Session, EXIT_NOTESTSCOLLECTED, _in_venv
 
-from _pytest.main import Session, EXIT_NOTESTSCOLLECTED
 
 class TestCollector(object):
     def test_collect_versus_item(self):
@@ -42,11 +44,11 @@ class TestCollector(object):
         assert not (fn1 == fn3)
         assert fn1 != fn3
 
-        for fn in fn1,fn2,fn3:
+        for fn in fn1, fn2, fn3:
             assert fn != 3
             assert fn != modcol
-            assert fn != [1,2,3]
-            assert [1,2,3] != fn
+            assert fn != [1, 2, 3]
+            assert [1, 2, 3] != fn
             assert modcol != fn
 
     def test_getparent(self, testdir):
@@ -68,7 +70,6 @@ class TestCollector(object):
         parent = fn.getparent(pytest.Class)
         assert parent is cls
 
-
     def test_getcustomfile_roundtrip(self, testdir):
         hello = testdir.makefile(".xxx", hello="world")
         testdir.makepyfile(conftest="""
@@ -102,6 +103,7 @@ class TestCollector(object):
             '*no tests ran in*',
         ])
 
+
 class TestCollectFS(object):
     def test_ignored_certain_directories(self, testdir):
         tmpdir = testdir.tmpdir
@@ -121,6 +123,53 @@ class TestCollectFS(object):
         assert "test_notfound" not in s
         assert "test_found" in s
 
+    @pytest.mark.parametrize('fname',
+                             ("activate", "activate.csh", "activate.fish",
+                              "Activate", "Activate.bat", "Activate.ps1"))
+    def test_ignored_virtualenvs(self, testdir, fname):
+        bindir = "Scripts" if py.std.sys.platform.startswith("win") else "bin"
+        testdir.tmpdir.ensure("virtual", bindir, fname)
+        testfile = testdir.tmpdir.ensure("virtual", "test_invenv.py")
+        testfile.write("def test_hello(): pass")
+
+        # by default, ignore tests inside a virtualenv
+        result = testdir.runpytest()
+        assert "test_invenv" not in result.stdout.str()
+        # allow test collection if user insists
+        result = testdir.runpytest("--collect-in-virtualenv")
+        assert "test_invenv" in result.stdout.str()
+        # allow test collection if user directly passes in the directory
+        result = testdir.runpytest("virtual")
+        assert "test_invenv" in result.stdout.str()
+
+    @pytest.mark.parametrize('fname',
+                             ("activate", "activate.csh", "activate.fish",
+                              "Activate", "Activate.bat", "Activate.ps1"))
+    def test_ignored_virtualenvs_norecursedirs_precedence(self, testdir, fname):
+        bindir = "Scripts" if py.std.sys.platform.startswith("win") else "bin"
+        # norecursedirs takes priority
+        testdir.tmpdir.ensure(".virtual", bindir, fname)
+        testfile = testdir.tmpdir.ensure(".virtual", "test_invenv.py")
+        testfile.write("def test_hello(): pass")
+        result = testdir.runpytest("--collect-in-virtualenv")
+        assert "test_invenv" not in result.stdout.str()
+        # ...unless the virtualenv is explicitly given on the CLI
+        result = testdir.runpytest("--collect-in-virtualenv", ".virtual")
+        assert "test_invenv" in result.stdout.str()
+
+    @pytest.mark.parametrize('fname',
+                             ("activate", "activate.csh", "activate.fish",
+                              "Activate", "Activate.bat", "Activate.ps1"))
+    def test__in_venv(self, testdir, fname):
+        """Directly test the virtual env detection function"""
+        bindir = "Scripts" if py.std.sys.platform.startswith("win") else "bin"
+        # no bin/activate, not a virtualenv
+        base_path = testdir.tmpdir.mkdir('venv')
+        assert _in_venv(base_path) is False
+        # with bin/activate, totally a virtualenv
+        base_path.ensure(bindir, fname)
+        assert _in_venv(base_path) is True
+
     def test_custom_norecursedirs(self, testdir):
         testdir.makeini("""
             [pytest]
@@ -334,6 +383,7 @@ class TestCustomConftests(object):
             "*test_x*"
         ])
 
+
 class TestSession(object):
     def test_parsearg(self, testdir):
         p = testdir.makepyfile("def test_func(): pass")
@@ -347,11 +397,11 @@ class TestSession(object):
         assert rcol.fspath == subdir
         parts = rcol._parsearg(p.basename)
 
-        assert parts[0] ==  target
+        assert parts[0] == target
         assert len(parts) == 1
         parts = rcol._parsearg(p.basename + "::test_func")
-        assert parts[0] ==  target
-        assert parts[1] ==  "test_func"
+        assert parts[0] == target
+        assert parts[1] == "test_func"
         assert len(parts) == 2
 
     def test_collect_topdir(self, testdir):
@@ -362,9 +412,9 @@ class TestSession(object):
         topdir = testdir.tmpdir
         rcol = Session(config)
         assert topdir == rcol.fspath
-        #rootid = rcol.nodeid
-        #root2 = rcol.perform_collect([rcol.nodeid], genitems=False)[0]
-        #assert root2 == rcol, rootid
+        # rootid = rcol.nodeid
+        # root2 = rcol.perform_collect([rcol.nodeid], genitems=False)[0]
+        # assert root2 == rcol, rootid
         colitems = rcol.perform_collect([rcol.nodeid], genitems=False)
         assert len(colitems) == 1
         assert colitems[0].fspath == p
@@ -460,7 +510,7 @@ class TestSession(object):
             ("pytest_collectstart", "collector.fspath == test_aaa"),
             ("pytest_pycollect_makeitem", "name == 'test_func'"),
             ("pytest_collectreport",
-                    "report.nodeid.startswith('aaa/test_aaa.py')"),
+             "report.nodeid.startswith('aaa/test_aaa.py')"),
         ])
 
     def test_collect_two_commandline_args(self, testdir):
@@ -510,6 +560,7 @@ class TestSession(object):
         # ensure we are reporting the collection of the single test item (#2464)
         assert [x.name for x in self.get_reported_items(hookrec)] == ['test_method']
 
+
 class Test_getinitialnodes(object):
     def test_global_file(self, testdir, tmpdir):
         x = tmpdir.ensure("x.py")
@@ -537,6 +588,7 @@ class Test_getinitialnodes(object):
         for col in col.listchain():
             assert col.config is config
 
+
 class Test_genitems(object):
     def test_check_collect_hashes(self, testdir):
         p = testdir.makepyfile("""
@@ -689,6 +741,7 @@ COLLECTION_ERROR_PY_FILES = dict(
     """,
 )
 
+
 def test_exit_on_collection_error(testdir):
     """Verify that all collection errors are collected and no tests executed"""
     testdir.makepyfile(**COLLECTION_ERROR_PY_FILES)
