@@ -1,10 +1,12 @@
 from __future__ import absolute_import, division, print_function
-import py, pytest
+import py
+import pytest
 
 import _pytest._code
-from _pytest.config import getcfg, get_common_ancestor, determine_setup
+from _pytest.config import getcfg, get_common_ancestor, determine_setup, _iter_rewritable_modules
 from _pytest.main import EXIT_NOTESTSCOLLECTED
 
+
 class TestParseIni(object):
 
     @pytest.mark.parametrize('section, filename',
@@ -85,6 +87,7 @@ class TestParseIni(object):
         result = testdir.inline_run("--confcutdir=.")
         assert result.ret == 0
 
+
 class TestConfigCmdlineParsing(object):
     def test_parsing_again_fails(self, testdir):
         config = testdir.parseconfig()
@@ -99,7 +102,7 @@ class TestConfigCmdlineParsing(object):
             [pytest]
             custom = 0
         """)
-        testdir.makefile(".cfg", custom = """
+        testdir.makefile(".cfg", custom="""
             [pytest]
             custom = 1
         """)
@@ -116,6 +119,7 @@ class TestConfigCmdlineParsing(object):
         ret = pytest.main("-c " + temp_cfg_file)
         assert ret == _pytest.main.EXIT_OK
 
+
 class TestConfigAPI(object):
     def test_config_trace(self, testdir):
         config = testdir.parseconfig()
@@ -149,7 +153,7 @@ class TestConfigAPI(object):
     def test_config_getvalueorskip(self, testdir):
         config = testdir.parseconfig()
         pytest.raises(pytest.skip.Exception,
-            "config.getvalueorskip('hello')")
+                      "config.getvalueorskip('hello')")
         verbose = config.getvalueorskip("verbose")
         assert verbose == config.option.verbose
 
@@ -304,6 +308,16 @@ class TestConfigAPI(object):
         config = testdir.parseconfig('--confcutdir', testdir.tmpdir.join('dir').ensure(dir=1))
         assert config.getoption('confcutdir') == str(testdir.tmpdir.join('dir'))
 
+    @pytest.mark.parametrize('names, expected', [
+        (['bar.py'], ['bar']),
+        (['foo', 'bar.py'], []),
+        (['foo', 'bar.pyc'], []),
+        (['foo', '__init__.py'], ['foo']),
+        (['foo', 'bar', '__init__.py'], []),
+    ])
+    def test_iter_rewritable_modules(self, names, expected):
+        assert list(_iter_rewritable_modules(['/'.join(names)])) == expected
+
 
 class TestConfigFromdictargs(object):
     def test_basic_behavior(self):
@@ -472,6 +486,7 @@ def test_plugin_preparse_prevents_setuptools_loading(testdir, monkeypatch):
     plugin = config.pluginmanager.getplugin("mytestplugin")
     assert plugin is None
 
+
 def test_cmdline_processargs_simple(testdir):
     testdir.makeconftest("""
         def pytest_cmdline_preparse(args):
@@ -483,6 +498,7 @@ def test_cmdline_processargs_simple(testdir):
         "*-h*",
     ])
 
+
 def test_invalid_options_show_extra_information(testdir):
     """display extra information when pytest exits due to unrecognized
     options in the command-line"""
@@ -528,6 +544,7 @@ def test_toolongargs_issue224(testdir):
     result = testdir.runpytest("-m", "hello" * 500)
     assert result.ret == EXIT_NOTESTSCOLLECTED
 
+
 def test_config_in_subdirectory_colon_command_line_issue2148(testdir):
     conftest_source = '''
         def pytest_addoption(parser):
@@ -569,7 +586,7 @@ def test_notify_exception(testdir, capfd):
 
 
 def test_load_initial_conftest_last_ordering(testdir):
-    from _pytest.config  import get_config
+    from _pytest.config import get_config
     pm = get_config().pluginmanager
 
     class My(object):
@@ -643,6 +660,7 @@ class TestWarning(object):
             *hello*
         """)
 
+
 class TestRootdir(object):
     def test_simple_noini(self, tmpdir):
         assert get_common_ancestor([tmpdir]) == tmpdir
@@ -666,7 +684,7 @@ class TestRootdir(object):
             rootdir, inifile, inicfg = determine_setup(None, args)
             assert rootdir == tmpdir
             assert inifile == inifile
-        rootdir, inifile, inicfg = determine_setup(None, [b,a])
+        rootdir, inifile, inicfg = determine_setup(None, [b, a])
         assert rootdir == tmpdir
         assert inifile == inifile
 
@@ -724,7 +742,6 @@ class TestOverrideIniArgs(object):
         assert result.ret == 0
         result.stdout.fnmatch_lines(["custom_option:3.0"])
 
-
     def test_override_ini_pathlist(self, testdir):
         testdir.makeconftest("""
             def pytest_addoption(parser):
@@ -826,4 +843,3 @@ class TestOverrideIniArgs(object):
             rootdir, inifile, inicfg = determine_setup(None, ['a/exist'])
             assert rootdir == tmpdir
             assert inifile is None
-
