@@ -6,7 +6,8 @@ import os
 import py
 import pytest
 import sys
-from _pytest import runner, main
+from _pytest import runner, main, outcomes
+
 
 class TestSetupState(object):
     def test_setup(self, testdir):
@@ -31,7 +32,7 @@ class TestSetupState(object):
             def setup_module(mod):
                 raise ValueError(42)
             def test_func(): pass
-        """) # noqa
+        """)  # noqa
         ss = runner.SetupState()
         pytest.raises(ValueError, lambda: ss.prepare(item))
         pytest.raises(ValueError, lambda: ss.prepare(item))
@@ -39,11 +40,14 @@ class TestSetupState(object):
     def test_teardown_multiple_one_fails(self, testdir):
         r = []
 
-        def fin1(): r.append('fin1')
+        def fin1():
+            r.append('fin1')
 
-        def fin2(): raise Exception('oops')
+        def fin2():
+            raise Exception('oops')
 
-        def fin3(): r.append('fin3')
+        def fin3():
+            r.append('fin3')
 
         item = testdir.getitem("def test_func(): pass")
         ss = runner.SetupState()
@@ -58,9 +62,11 @@ class TestSetupState(object):
     def test_teardown_multiple_fail(self, testdir):
         # Ensure the first exception is the one which is re-raised.
         # Ideally both would be reported however.
-        def fin1(): raise Exception('oops1')
+        def fin1():
+            raise Exception('oops1')
 
-        def fin2(): raise Exception('oops2')
+        def fin2():
+            raise Exception('oops2')
 
         item = testdir.getitem("def test_func(): pass")
         ss = runner.SetupState()
@@ -94,7 +100,7 @@ class BaseFunctionalTests(object):
         assert rep.failed
         assert rep.when == "call"
         assert rep.outcome == "failed"
-        #assert isinstance(rep.longrepr, ReprExceptionInfo)
+        # assert isinstance(rep.longrepr, ReprExceptionInfo)
 
     def test_skipfunction(self, testdir):
         reports = testdir.runitem("""
@@ -107,12 +113,12 @@ class BaseFunctionalTests(object):
         assert not rep.passed
         assert rep.skipped
         assert rep.outcome == "skipped"
-        #assert rep.skipped.when == "call"
-        #assert rep.skipped.when == "call"
-        #assert rep.skipped == "%sreason == "hello"
-        #assert rep.skipped.location.lineno == 3
-        #assert rep.skipped.location.path
-        #assert not rep.skipped.failurerepr
+        # assert rep.skipped.when == "call"
+        # assert rep.skipped.when == "call"
+        # assert rep.skipped == "%sreason == "hello"
+        # assert rep.skipped.location.lineno == 3
+        # assert rep.skipped.location.path
+        # assert not rep.skipped.failurerepr
 
     def test_skip_in_setup_function(self, testdir):
         reports = testdir.runitem("""
@@ -127,11 +133,11 @@ class BaseFunctionalTests(object):
         assert not rep.failed
         assert not rep.passed
         assert rep.skipped
-        #assert rep.skipped.reason == "hello"
-        #assert rep.skipped.location.lineno == 3
-        #assert rep.skipped.location.lineno == 3
+        # assert rep.skipped.reason == "hello"
+        # assert rep.skipped.location.lineno == 3
+        # assert rep.skipped.location.lineno == 3
         assert len(reports) == 2
-        assert reports[1].passed # teardown
+        assert reports[1].passed  # teardown
 
     def test_failure_in_setup_function(self, testdir):
         reports = testdir.runitem("""
@@ -163,8 +169,8 @@ class BaseFunctionalTests(object):
         assert not rep.passed
         assert rep.failed
         assert rep.when == "teardown"
-        #assert rep.longrepr.reprcrash.lineno == 3
-        #assert rep.longrepr.reprtraceback.reprentries
+        # assert rep.longrepr.reprcrash.lineno == 3
+        # assert rep.longrepr.reprtraceback.reprentries
 
     def test_custom_failure_repr(self, testdir):
         testdir.makepyfile(conftest="""
@@ -182,10 +188,10 @@ class BaseFunctionalTests(object):
         assert not rep.skipped
         assert not rep.passed
         assert rep.failed
-        #assert rep.outcome.when == "call"
-        #assert rep.failed.where.lineno == 3
-        #assert rep.failed.where.path.basename == "test_func.py"
-        #assert rep.failed.failurerepr == "hello"
+        # assert rep.outcome.when == "call"
+        # assert rep.failed.where.lineno == 3
+        # assert rep.failed.where.path.basename == "test_func.py"
+        # assert rep.failed.failurerepr == "hello"
 
     def test_teardown_final_returncode(self, testdir):
         rec = testdir.inline_runsource("""
@@ -220,14 +226,14 @@ class BaseFunctionalTests(object):
                 raise ValueError(42)
         """)
         reps = rec.getreports("pytest_runtest_logreport")
-        print (reps)
+        print(reps)
         for i in range(2):
             assert reps[i].nodeid.endswith("test_method")
             assert reps[i].passed
         assert reps[2].when == "teardown"
         assert reps[2].failed
         assert len(reps) == 6
-        for i in range(3,5):
+        for i in range(3, 5):
             assert reps[i].nodeid.endswith("test_func")
             assert reps[i].passed
         assert reps[5].when == "teardown"
@@ -247,7 +253,7 @@ class BaseFunctionalTests(object):
                     assert True
         """)
         reps = rec.getreports("pytest_runtest_logreport")
-        print (reps)
+        print(reps)
         assert len(reps) == 3
         #
         assert reps[0].nodeid.endswith("test_method")
@@ -262,11 +268,11 @@ class BaseFunctionalTests(object):
         assert reps[2].failed
         assert reps[2].when == "teardown"
         assert reps[2].longrepr.reprcrash.message in (
-                # python3 error
-                "TypeError: teardown_method() missing 2 required positional arguments: 'y' and 'z'",
-                # python2 error
-                'TypeError: teardown_method() takes exactly 4 arguments (2 given)'
-                )
+            # python3 error
+            "TypeError: teardown_method() missing 2 required positional arguments: 'y' and 'z'",
+            # python2 error
+            'TypeError: teardown_method() takes exactly 4 arguments (2 given)'
+        )
 
     def test_failure_in_setup_function_ignores_custom_repr(self, testdir):
         testdir.makepyfile(conftest="""
@@ -287,10 +293,10 @@ class BaseFunctionalTests(object):
         assert not rep.skipped
         assert not rep.passed
         assert rep.failed
-        #assert rep.outcome.when == "setup"
-        #assert rep.outcome.where.lineno == 3
-        #assert rep.outcome.where.path.basename == "test_func.py"
-        #assert instanace(rep.failed.failurerepr, PythonFailureRepr)
+        # assert rep.outcome.when == "setup"
+        # assert rep.outcome.where.lineno == 3
+        # assert rep.outcome.where.path.basename == "test_func.py"
+        # assert instanace(rep.failed.failurerepr, PythonFailureRepr)
 
     def test_systemexit_does_not_bail_out(self, testdir):
         try:
@@ -316,6 +322,7 @@ class BaseFunctionalTests(object):
         else:
             pytest.fail("did not raise")
 
+
 class TestExecutionNonForked(BaseFunctionalTests):
     def getrunner(self):
         def f(item):
@@ -333,6 +340,7 @@ class TestExecutionNonForked(BaseFunctionalTests):
         else:
             pytest.fail("did not raise")
 
+
 class TestExecutionForked(BaseFunctionalTests):
     pytestmark = pytest.mark.skipif("not hasattr(os, 'fork')")
 
@@ -351,6 +359,7 @@ class TestExecutionForked(BaseFunctionalTests):
         assert rep.failed
         assert rep.when == "???"
 
+
 class TestSessionReports(object):
     def test_collect_result(self, testdir):
         col = testdir.getmodulecol("""
@@ -380,6 +389,7 @@ reporttypes = [
     runner.CollectReport,
 ]
 
+
 @pytest.mark.parametrize('reporttype', reporttypes, ids=[x.__name__ for x in reporttypes])
 def test_report_extra_parameters(reporttype):
     if hasattr(py.std.inspect, 'signature'):
@@ -390,12 +400,13 @@ def test_report_extra_parameters(reporttype):
     report = reporttype(newthing=1, **basekw)
     assert report.newthing == 1
 
+
 def test_callinfo():
     ci = runner.CallInfo(lambda: 0, '123')
     assert ci.when == "123"
     assert ci.result == 0
     assert "result" in repr(ci)
-    ci = runner.CallInfo(lambda: 0/0, '123')
+    ci = runner.CallInfo(lambda: 0 / 0, '123')
     assert ci.when == "123"
     assert not hasattr(ci, 'result')
     assert ci.excinfo
@@ -403,6 +414,8 @@ def test_callinfo():
 
 # design question: do we want general hooks in python files?
 # then something like the following functional tests makes sense
+
+
 @pytest.mark.xfail
 def test_runtest_in_module_ordering(testdir):
     p1 = testdir.makepyfile("""
@@ -436,9 +449,18 @@ def test_runtest_in_module_ordering(testdir):
 
 
 def test_outcomeexception_exceptionattributes():
-    outcome = runner.OutcomeException('test')
+    outcome = outcomes.OutcomeException('test')
     assert outcome.args[0] == outcome.msg
 
+
+def test_outcomeexception_passes_except_Exception():
+    with pytest.raises(outcomes.OutcomeException):
+        try:
+            raise outcomes.OutcomeException('test')
+        except Exception:
+            pass
+
+
 def test_pytest_exit():
     try:
         pytest.exit("hello")
@@ -446,6 +468,7 @@ def test_pytest_exit():
         excinfo = _pytest._code.ExceptionInfo()
         assert excinfo.errisinstance(KeyboardInterrupt)
 
+
 def test_pytest_fail():
     try:
         pytest.fail("hello")
@@ -454,6 +477,7 @@ def test_pytest_fail():
         s = excinfo.exconly(tryshort=True)
         assert s.startswith("Failed")
 
+
 def test_pytest_exit_msg(testdir):
     testdir.makeconftest("""
     import pytest
@@ -466,6 +490,7 @@ def test_pytest_exit_msg(testdir):
         "Exit: oh noes",
     ])
 
+
 def test_pytest_fail_notrace(testdir):
     testdir.makepyfile("""
         import pytest
@@ -531,6 +556,7 @@ def test_exception_printing_skip():
         s = excinfo.exconly(tryshort=True)
         assert s.startswith("Skipped")
 
+
 def test_importorskip(monkeypatch):
     importorskip = pytest.importorskip
 
@@ -540,8 +566,8 @@ def test_importorskip(monkeypatch):
     try:
         sys = importorskip("sys")  # noqa
         assert sys == py.std.sys
-        #path = pytest.importorskip("os.path")
-        #assert path == py.std.os.path
+        # path = pytest.importorskip("os.path")
+        # assert path == py.std.os.path
         excinfo = pytest.raises(pytest.skip.Exception, f)
         path = py.path.local(excinfo.getrepr().reprcrash.path)
         # check that importorskip reports the actual call
@@ -561,10 +587,12 @@ def test_importorskip(monkeypatch):
         print(_pytest._code.ExceptionInfo())
         pytest.fail("spurious skip")
 
+
 def test_importorskip_imports_last_module_part():
     ospath = pytest.importorskip("os.path")
     assert os.path == ospath
 
+
 def test_importorskip_dev_module(monkeypatch):
     try:
         mod = py.std.types.ModuleType("mockmodule")
@@ -681,6 +709,8 @@ def test_store_except_info_on_eror():
     """
     # Simulate item that raises a specific exception
     class ItemThatRaises(object):
+        nodeid = 'item_that_raises'
+
         def runtest(self):
             raise IndexError('TEST')
     try:
@@ -693,6 +723,31 @@ def test_store_except_info_on_eror():
     assert sys.last_traceback
 
 
+def test_current_test_env_var(testdir, monkeypatch):
+    pytest_current_test_vars = []
+    monkeypatch.setattr(sys, 'pytest_current_test_vars', pytest_current_test_vars, raising=False)
+    testdir.makepyfile('''
+        import pytest
+        import sys
+        import os
+
+        @pytest.fixture
+        def fix():
+            sys.pytest_current_test_vars.append(('setup', os.environ['PYTEST_CURRENT_TEST']))
+            yield
+            sys.pytest_current_test_vars.append(('teardown', os.environ['PYTEST_CURRENT_TEST']))
+
+        def test(fix):
+            sys.pytest_current_test_vars.append(('call', os.environ['PYTEST_CURRENT_TEST']))
+    ''')
+    result = testdir.runpytest_inprocess()
+    assert result.ret == 0
+    test_id = 'test_current_test_env_var.py::test'
+    assert pytest_current_test_vars == [
+        ('setup', test_id + ' (setup)'), ('call', test_id + ' (call)'), ('teardown', test_id + ' (teardown)')]
+    assert 'PYTEST_CURRENT_TEST' not in os.environ
+
+
 class TestReportContents(object):
     """
     Test user-level API of ``TestReport`` objects.
@@ -754,5 +809,3 @@ class TestReportContents(object):
         rep = reports[1]
         assert rep.capstdout == ''
         assert rep.capstderr == ''
-
-
