@@ -31,6 +31,7 @@ class Option(object):
             l.append('--fulltrace')
         return l
 
+
 def pytest_generate_tests(metafunc):
     if "option" in metafunc.fixturenames:
         metafunc.addcall(id="default",
@@ -38,7 +39,7 @@ def pytest_generate_tests(metafunc):
         metafunc.addcall(id="verbose",
                          funcargs={'option': Option(verbose=True)})
         metafunc.addcall(id="quiet",
-                         funcargs={'option': Option(verbose= -1)})
+                         funcargs={'option': Option(verbose=-1)})
         metafunc.addcall(id="fulltrace",
                          funcargs={'option': Option(fulltrace=True)})
 
@@ -77,8 +78,8 @@ class TestTerminal(object):
             ])
         else:
             result.stdout.fnmatch_lines([
-            "*test_pass_skip_fail.py .sF"
-        ])
+                "*test_pass_skip_fail.py .sF"
+            ])
         result.stdout.fnmatch_lines([
             "    def test_func():",
             ">       assert 0",
@@ -110,7 +111,7 @@ class TestTerminal(object):
         item.config.pluginmanager.register(tr)
         location = item.reportinfo()
         tr.config.hook.pytest_runtest_logstart(nodeid=item.nodeid,
-            location=location, fspath=str(item.fspath))
+                                               location=location, fspath=str(item.fspath))
         linecomp.assert_contains_lines([
             "*test_show_runtest_logstart.py*"
         ])
@@ -213,6 +214,16 @@ class TestTerminal(object):
         result = testdir.runpytest()
         result.stdout.fnmatch_lines(['collected 1 item'])
 
+    def test_rewrite(self, testdir, monkeypatch):
+        config = testdir.parseconfig()
+        f = py.io.TextIO()
+        monkeypatch.setattr(f, 'isatty', lambda *args: True)
+        tr = TerminalReporter(config, f)
+        tr.writer.fullwidth = 10
+        tr.write('hello')
+        tr.rewrite('hey', erase=True)
+        assert f.getvalue() == 'hello' + '\r' + 'hey' + (7 * ' ')
+
 
 class TestCollectonly(object):
     def test_collectonly_basic(self, testdir):
@@ -222,8 +233,8 @@ class TestCollectonly(object):
         """)
         result = testdir.runpytest("--collect-only",)
         result.stdout.fnmatch_lines([
-           "<Module 'test_collectonly_basic.py'>",
-           "  <Function 'test_func'>",
+            "<Module 'test_collectonly_basic.py'>",
+            "  <Function 'test_func'>",
         ])
 
     def test_collectonly_skipped_module(self, testdir):
@@ -264,13 +275,13 @@ class TestCollectonly(object):
                     pass
         """)
         result = testdir.runpytest("--collect-only", p)
-        #assert stderr.startswith("inserting into sys.path")
+        # assert stderr.startswith("inserting into sys.path")
         assert result.ret == 0
         result.stdout.fnmatch_lines([
             "*<Module '*.py'>",
             "* <Function 'test_func1'*>",
             "* <Class 'TestClass'>",
-            #"*  <Instance '()'>",
+            # "*  <Instance '()'>",
             "*   <Function 'test_method'*>",
         ])
 
@@ -318,7 +329,8 @@ def test_repr_python_version(monkeypatch):
         py.std.sys.version_info = x = (2, 3)
         assert repr_pythonversion() == str(x)
     finally:
-        monkeypatch.undo() # do this early as pytest can get confused
+        monkeypatch.undo()  # do this early as pytest can get confused
+
 
 class TestFixtureReporting(object):
     def test_setup_fixture_error(self, testdir):
@@ -378,7 +390,7 @@ class TestFixtureReporting(object):
             "*def test_fail():",
             "*failingfunc*",
             "*1 failed*1 error*",
-         ])
+        ])
 
     def test_setup_teardown_output_and_test_failure(self, testdir):
         """ Test for issue #442 """
@@ -403,7 +415,8 @@ class TestFixtureReporting(object):
             "*teardown func*",
 
             "*1 failed*",
-         ])
+        ])
+
 
 class TestTerminalFunctional(object):
     def test_deselected(self, testdir):
@@ -415,7 +428,7 @@ class TestTerminalFunctional(object):
                 def test_three():
                     pass
            """
-        )
+                                      )
         result = testdir.runpytest("-k", "test_two:", testpath)
         result.stdout.fnmatch_lines([
             "*test_deselected.py ..",
@@ -485,7 +498,7 @@ class TestTerminalFunctional(object):
         """)
         result = testdir.runpytest(p1, '-l')
         result.stdout.fnmatch_lines([
-            #"_ _ * Locals *",
+            # "_ _ * Locals *",
             "x* = 3",
             "y* = 'xxxxxx*"
         ])
@@ -541,6 +554,23 @@ class TestTerminalFunctional(object):
         assert "===" not in s
         assert "passed" not in s
 
+    def test_report_collectionfinish_hook(self, testdir):
+        testdir.makeconftest("""
+            def pytest_report_collectionfinish(config, startdir, items):
+                return ['hello from hook: {0} items'.format(len(items))]
+        """)
+        testdir.makepyfile("""
+            import pytest
+            @pytest.mark.parametrize('i', range(3))
+            def test(i):
+                pass
+        """)
+        result = testdir.runpytest()
+        result.stdout.fnmatch_lines([
+            "collected 3 items",
+            "hello from hook: 3 items",
+        ])
+
 
 def test_fail_extra_reporting(testdir):
     testdir.makepyfile("def test_this(): assert 0")
@@ -552,11 +582,13 @@ def test_fail_extra_reporting(testdir):
         "FAIL*test_fail_extra_reporting*",
     ])
 
+
 def test_fail_reporting_on_pass(testdir):
     testdir.makepyfile("def test_this(): assert 1")
     result = testdir.runpytest('-rf')
     assert 'short test summary' not in result.stdout.str()
 
+
 def test_pass_extra_reporting(testdir):
     testdir.makepyfile("def test_this(): assert 1")
     result = testdir.runpytest()
@@ -567,11 +599,13 @@ def test_pass_extra_reporting(testdir):
         "PASS*test_pass_extra_reporting*",
     ])
 
+
 def test_pass_reporting_on_fail(testdir):
     testdir.makepyfile("def test_this(): assert 0")
     result = testdir.runpytest('-rp')
     assert 'short test summary' not in result.stdout.str()
 
+
 def test_pass_output_reporting(testdir):
     testdir.makepyfile("""
         def test_pass_output():
@@ -584,6 +618,7 @@ def test_pass_output_reporting(testdir):
         "Four score and seven years ago...",
     ])
 
+
 def test_color_yes(testdir):
     testdir.makepyfile("def test_this(): assert 1")
     result = testdir.runpytest('--color=yes')
@@ -660,6 +695,7 @@ def test_terminalreporter_reportopt_addopts(testdir):
         "*1 passed*"
     ])
 
+
 def test_tbstyle_short(testdir):
     p = testdir.makepyfile("""
         import pytest
@@ -685,6 +721,7 @@ def test_tbstyle_short(testdir):
     assert 'x = 0' in s
     assert 'assert x' in s
 
+
 def test_traceconfig(testdir, monkeypatch):
     result = testdir.runpytest("--traceconfig")
     result.stdout.fnmatch_lines([
@@ -697,6 +734,7 @@ class TestGenericReporting(object):
     """ this test class can be subclassed with a different option
         provider to run e.g. distributed tests.
     """
+
     def test_collect_fail(self, testdir, option):
         testdir.makepyfile("import xyz\n")
         result = testdir.runpytest(*option.args)
@@ -723,7 +761,6 @@ class TestGenericReporting(object):
             "*2 failed*",
         ])
 
-
     def test_tb_option(self, testdir, option):
         testdir.makepyfile("""
             import pytest
@@ -787,6 +824,7 @@ def pytest_report_header(config, startdir):
             str(testdir.tmpdir),
         ])
 
+
 @pytest.mark.xfail("not hasattr(os, 'dup')")
 def test_fdopen_kept_alive_issue124(testdir):
     testdir.makepyfile("""
@@ -805,6 +843,7 @@ def test_fdopen_kept_alive_issue124(testdir):
         "*2 passed*"
     ])
 
+
 def test_tbstyle_native_setup_error(testdir):
     testdir.makepyfile("""
         import pytest
@@ -817,8 +856,9 @@ def test_tbstyle_native_setup_error(testdir):
     """)
     result = testdir.runpytest("--tb=native")
     result.stdout.fnmatch_lines([
-            '*File *test_tbstyle_native_setup_error.py", line *, in setup_error_fixture*'
-            ])
+        '*File *test_tbstyle_native_setup_error.py", line *, in setup_error_fixture*'
+    ])
+
 
 def test_terminal_summary(testdir):
     testdir.makeconftest("""
@@ -872,7 +912,7 @@ def test_terminal_summary_warnings_are_displayed(testdir):
     ("yellow", "1 passed, 1 warnings", {"warnings": (1,),
                                         "passed": (1,)}),
 
-    ("green", "5 passed", {"passed": (1,2,3,4,5)}),
+    ("green", "5 passed", {"passed": (1, 2, 3, 4, 5)}),
 
 
     # "Boring" statuses.  These have no effect on the color of the summary
@@ -901,13 +941,13 @@ def test_terminal_summary_warnings_are_displayed(testdir):
 
     # A couple more complex combinations
     ("red", "1 failed, 2 passed, 3 xfailed",
-        {"passed": (1,2), "failed": (1,), "xfailed": (1,2,3)}),
+        {"passed": (1, 2), "failed": (1,), "xfailed": (1, 2, 3)}),
 
     ("green", "1 passed, 2 skipped, 3 deselected, 2 xfailed",
         {"passed": (1,),
-        "skipped": (1,2),
-        "deselected": (1,2,3),
-        "xfailed": (1,2)}),
+         "skipped": (1, 2),
+         "deselected": (1, 2, 3),
+         "xfailed": (1, 2)}),
 ])
 def test_summary_stats(exp_line, exp_color, stats_arg):
     print("Based on stats: %s" % stats_arg)
